Player = {}

-- Constructor
function Player:new()
	-- define our parameters here
	local object = {
    x = 200,
    y = 120,
    width = 25,
    height = 40,
    xSpeed = 0,
    ySpeed = 0,
    state = "",
    jumpSpeed = -950,
    runSpeed = 500,
    canJump = false,
	maxY = 539,
	imageFlipX = 1,
	imageOffsetX = 0
    }
	setmetatable(object, {__index = Player})
	return object
end

function Player:load()
	local g = anim8.newGrid(25, 40, player:getWidth(), player:getHeight())
	animation = anim8.newAnimation(g(1,'1 - 3'), 0.1)
end

-- Movement functions
function Player:jump()
	if self.canJump == true then
		self.ySpeed = self.jumpSpeed
		self.canJump = false
	end
end

function Player:moveRight()
	self.xSpeed = self.runSpeed
	self.state = "moveRight"
	self.imageFlipX = -1
    self.imageOffsetX = self.width
end

function Player:moveLeft()
	self.xSpeed = -1 * (self.runSpeed)
	self.state = "moveLeft"
	self.imageFlipX = 1
    self.imageOffsetX = 0
end

function Player:stop()
	self.xSpeed = 0
end

function Player:hitFloor()
	p.ySpeed = 0
	p.xSpeed = 0
	if p.y > p.maxY then
		p.y = p.maxY         -- If the player sinks into the ground return him to the surface
	end
	p.canJump = true
end

-- Update function
function Player:update(dt, gravity)
	-- update the player's position
	self.x = self.x + (self.xSpeed * dt)
	self.y = self.y + (self.ySpeed * dt)
	playerBox:move(self.xSpeed * dt, self.ySpeed * dt)
	playerBox:moveTo(self.x + 12, self.y + 20)
	animation:update(dt)
	
	-- apply gravity
	self.ySpeed = self.ySpeed + (gravity * dt)
	
	-- update the player's state
	if not(self.canJump) then
		if self.ySpeed < 0 then
			self.state = "jump"
		elseif self.ySpeed > 0 then
			self.state = "fall"
		end
	else
		if self.xSpeed > 0 then
			self.state = "moveRight"
		animation:flipH()
		elseif self.xSpeed < 0 then
			self.state = "moveLeft"
			animation:flipH()
		else
			self.state = "stand"
		end
	end
end

function Player:draw()
	animation:draw(player, p.x, p.y)
end